package io.renren.modules.app.dao;

import java.util.List;

import org.apache.ibatis.annotations.Mapper;

import com.baomidou.mybatisplus.mapper.BaseMapper;

import io.renren.modules.app.entity.FwxxEntity;
import io.renren.modules.app.entity.HomePage_SsywblEntity;
import io.renren.modules.app.entity.JczqqsEntity;
import io.renren.modules.app.entity.YwpzEntity;
/**
 * 首页大数据展示
 * @author Administrator
 *
 */
import io.renren.modules.app.entity.ZhxxEntity;
import org.apache.ibatis.annotations.Param;

@Mapper
public interface HomePageDao extends BaseMapper<HomePage_SsywblEntity> {
	/**
	 * 查询实时业务办理
	 * @return
	 */
	List<HomePage_SsywblEntity> selectSsywbl();

	Integer selectsfjz(@Param("djbh") String djbh);

	Integer selectsfjs(@Param("jsdbh")String jsdbh);

	/**
	 * 当月单位缴纳 
	 * @return
	 */
	String selectDydwjk();
	
	/**
	 * 当月个人缴纳 
	 * @return
	 */
	String selectDygrjk();
	
	/**
	 * 当月个人支出
	 * @return
	 */
	String selectDygrzc();
	
	/**
	 * 当年单位缴纳
	 * @return
	 */
	String selectDndwjk();
	
	/**
	 * 当年个人缴纳 
	 * @return
	 */
	String selectDngrjk();
	
	/**
	 * 当年个人支出 
	 * @return
	 */
	String selectDngrzc();
	
	List<String> selectdhbm01();
	
	List<String> selectdhbm03();
	
	String selectxmbm(String id);
	
	YwpzEntity selectyjnje();
	
	YwpzEntity selectyzcje();
	
	YwpzEntity selectdwsjje();
	
	List<ZhxxEntity> selelctzhxx();
	
	YwpzEntity selectgrsjje();
	
	List<FwxxEntity> selectfwxx();
	
	JczqqsEntity selectjcje(String id);
	
	JczqqsEntity selectzqje(String id);
}
